Features
========

JAX-in-Cell can run in CPUs, GPUs and TPUs, has autodifferentiation and just-in-time compilation capabilities, is based on rigorous testing, uses CI/CD via GitHub actions and has detailed documentation.

Currently, it evolves particles using the non-relativisic Lorentz force
:math:`\mathbf F = q (\mathbf E + \mathbf v \times \mathbf B)`,
and evolves the electric :math:`\mathbf E` and magnetic :math:`\mathbf B`
fields using Maxwell's equations.

Plenty of examples are provided in the ``examples`` folder, and the documentation is on Read the Docs:
https://jax-in-cell.readthedocs.io/
